@@ -177,7 +177,7 @@ public:
         connect(this, SIGNAL(slotActivated(const QString &)), receiver, slot);
         parent->addAction(phrase, this);
     }
-    ~PhraseAction()
+    ~PhraseAction() override
     {
     }
 
@@ -185,7 +185,7 @@ public Q_SLOTS:
     void slotTriggered()
     {
 //      trigger();
-        emit slotActivated(phrase);
+        Q_EMIT slotActivated(phrase);
     }
 
 Q_SIGNALS:
